@@ -18,11 +18,27 @@
 /// from SuperLU_DIST. For its use see SuperLUMatrix for more
 /// information.
 	void
+#ifdef SLU_MAJOR_VERSION
+#if SLU_MAJOR_VERSION < 5 
 pzsymbfact(superlu_options_t *options, SuperMatrix *A, 
 					 ScalePermstruct_t *ScalePermstruct, gridinfo_t *grid,
 					 LUstruct_t *LUstruct, SuperLUStat_t *stat, 
 					 int *numProcSymbFact, int *info, double *totalMemory,
 					 double *maxMemory)
+#else
+pzsymbfact(superlu_dist_options_t *options, SuperMatrix *A, 
+					 ScalePermstruct_t *ScalePermstruct, gridinfo_t *grid,
+					 LUstruct_t *LUstruct, SuperLUStat_t *stat, 
+					 int *numProcSymbFact, int *info, double *totalMemory,
+					 double *maxMemory)
+#endif
+#else
+pzsymbfact(superlu_dist_options_t *options, SuperMatrix *A, 
+					 ScalePermstruct_t *ScalePermstruct, gridinfo_t *grid,
+					 LUstruct_t *LUstruct, SuperLUStat_t *stat, 
+					 int *numProcSymbFact, int *info, double *totalMemory,
+					 double *maxMemory)
+#endif
 {
 	NRformat_loc *Astore;
 	SuperMatrix GA;      /* Global A in NC format */
@@ -61,7 +77,16 @@ pzsymbfact(superlu_options_t *options, SuperMatrix *A,
 	double   t;
 	float    GA_mem_use;    /* memory usage by global A */
 	float    dist_mem_use; /* memory usage during distribution */
+	//mem_usage_t num_mem_usage, symb_mem_usage;
+#ifdef SLU_MAJOR_VERSION
+#if SLU_MAJOR_VERSION < 5
 	mem_usage_t num_mem_usage, symb_mem_usage;
+#else
+	superlu_dist_mem_usage_t num_mem_usage, symb_mem_usage;
+#endif
+#else
+	superlu_dist_mem_usage_t num_mem_usage, symb_mem_usage;
+#endif
 #if ( PRNTlevel>= 2 )
 	double   dmin, dsum, dprod;
 #endif
@@ -89,6 +114,9 @@ pzsymbfact(superlu_options_t *options, SuperMatrix *A,
 	symb_comm = MPI_COMM_NULL;
 	symb_mem_usage.total = 0.;
 
+  /* Suggested from Valgrind debugging by Patrick Seewald */
+  stat->peak_buffer    = 0.0;
+
 	/* Test the input parameters. */
 	*info = 0;
 	Fact = options->Fact;
